==> ch_gb_v1.60.zip: ch_gb_v1.60/myGB/myGB-admin/frame.php <==
<?php include("logincheck.php") ?>
<?php

	include('../../myGB-config.inc.php');

	if( $_REQUEST['del'] == 'true' and isset($_REQUEST['eintrag']) )
	{
		$eintraege = @file('../../'.$textfile);
		$max = count($eintraege);
		$openfile = fopen('../../'.$textfile, "w");
		for( $a=0; $a<$max; $a++)
		{
			if($a != $_REQUEST['eintrag'])
			{
				flock($openfile,2);
				fwrite($openfile,$eintraege[$a]);
				flock($openfile,3);
			}
		}
		fclose($openfile);
	}
	if( isset($_POST['submit']) and isset($_REQUEST['eintrag']) )
	{
		$eintraege = @file('../../'.$textfile);
		$max = count($eintraege);
		$openfile = fopen('../../'.$textfile, "w");
		for( $a=0; $a<$max; $a++)
		{
			if($a != $_REQUEST['eintrag'])
			{
				flock($openfile,2);
				fwrite($openfile,$eintraege[$a]);
				flock($openfile,3);
			}
			else
			{
				if($_POST['komment'] != '')
				{
					$eintraege[$a] = trim($eintraege[$a]);
					$eintraege[$a] = $eintraege[$a].'<ul><li style="list-style: none"><i>'.$_POST['komment'].'</i></li></ul>'."\r\n";
					flock($openfile,2);
					fwrite($openfile,$eintraege[$a]);
					flock($openfile,3);
				}
			}
		}
		fclose($openfile);
	}

	include('../myGB-lib/bbcode.php');
	
	if (!isset($_REQUEST['page'])) $page = 1;
	else $page = $_REQUEST['page'];
	
	$eintraege = @file('../../'.$textfile);
	$start = (count($eintraege) - 1) - $seiten * ($page - 1);
	$stop = (count($eintraege) - 1) - $seiten * ($page - 1) - $seiten + 1;
	if ($start > (count($eintraege) - 1)) $start = count($eintraege) - 1;
	
	if ($stop < 0) $stop = 0;

	if( ($eintraege > 0) and isset($eintraege) )
	{
		$max = count($eintraege);
		for ($a = $start; $a >= $stop; $a--)
		{
			$Eintrag = explode("|", $eintraege[$a]);
			$Eintrag[4] = str_replace('src="'.$smileypath, 'src="../../'.$smileypath, $Eintrag[4]);
			$Eintrag[4] = str_replace("src='".$smileypath, "src='../../".$smileypath, $Eintrag[4]);
?>
	<form action="frame.php?<?php echo htmlspecialchars(SID); ?>" method="POST">

	<table style="border: 1px solid #000000; width: 500px; margin: auto" cellpadding="0" cellspacing="0">
	<tr>
		<td rowspan="3" style="padding: 0.1em; width: 50px; text-align: center; border-right: 1px solid #000000">
			<a onclick="return confirm('Wirklich lschen?');" href="frame.php?id=<?php echo session_id();?>&del=true&eintrag=<?php echo $a;?>"><img src="../../smilies/form/del.gif"></a>
		</td>
		<td style="padding: 0.1em;">
			<b><?php echo $Eintrag[0];?></b> &nbsp;
			am  <b><?php echo $Eintrag[3];?></b> &nbsp;
			<?php if($Eintrag[2]=='') { echo'&nbsp;'; } else { echo ' <a href="mailto:'.$Eintrag[2].'"><img src="../../smilies/mail.gif"></a> &nbsp; '; } ?>
			<?php if(($Eintrag[1]=='')or($Eintrag[1]=='http://')) { echo'&nbsp;'; } else { echo ' <a href="'.$Eintrag[1].'" target="_blank"><img src="../../smilies/hpage.gif"></a> &nbsp;'; } ?>
		</td>
	</tr>
	<tr>
		<td style="padding: 0.3em;; overflow: auto">
			<?php echo myGB_bbcodesmilie(stripslashes(nl2br($Eintrag[4])), true) ?>
		</td>
	</tr>
	<tr align="center">
		<td style="text-align: center; border-top: 1px solid #000000; padding: 0.1em;">
			Kommentar: <input type="text" name="komment">
			<input type="submit" name="submit" value="Kommentieren">
			<input type="hidden" name="eintrag" value="<?php echo $a;?>">
		</td>
	</tr>
	</table>
	<br>
	
	</form>

<?php
		}
	}
?>
	<div class="links">
<?php

	if( !isset($max) or $max == '' ) $max = 0;
	
	if ($max == 0) $pages = 1;
	else $pages = intval(($max - 1) / $seiten) + 1;

	// Links zu den einzelnen Seiten ausgeben
	if ($page > 1)
	{
		echo ' <a href="'.$_SERVER['PHP_SELF'].'?page=1">|<</a> ';
		echo ' <a href="'.$_SERVER['PHP_SELF'].'?page='.($page - 1).'"><</a> ';
	}

	for ($i = 1; $i <= $pages; $i++)
	{
		if ($i == $page) echo ' <b>['.$i.']</b> ';
		else echo ' <a href="'.$_SERVER['PHP_SELF'].'?page='.$i.'">'.$i.'</a> ';
	}

	if($page < $pages)
	{
		echo ' <a href="'.$_SERVER['PHP_SELF'].'?page='.($page + 1).'"><</a> ';
		echo ' <a href="'.$_SERVER['PHP_SELF'].'?page='.$pages.'">>|</a> ';
	}
?>
	<br>Es sind <b><?php echo $max; ?></b> Eintr&auml;ge im G&auml;stebuch<br><br>
	
	</div>
	
	</div>
	
</body>
</html>

==> ch_gb_v1.61.zip: ch_gb_v1.61/myGB/myGB-admin/frame.php <==
<?php include("logincheck.php") ?>
<?php

	include('../../myGB-config.inc.php');

	if( $_REQUEST['del'] == 'true' and isset($_REQUEST['eintrag']) )
	{
		$eintraege = @file('../../'.$textfile);
		$max = count($eintraege);
		$openfile = fopen('../../'.$textfile, "w");
		for( $a=0; $a<$max; $a++)
		{
			if($a != $_REQUEST['eintrag'])
			{
				flock($openfile,2);
				fwrite($openfile,$eintraege[$a]);
				flock($openfile,3);
			}
		}
		fclose($openfile);
	}
	if( isset($_POST['submit']) and isset($_REQUEST['eintrag']) )
	{
		$eintraege = @file('../../'.$textfile);
		$max = count($eintraege);
		$openfile = fopen('../../'.$textfile, "w");
		$_REQUEST['eintrag'] = (int) $_REQUEST['eintrag'];
		for($a = 0; $a < $max; $a++)
		{
			if($a == $_REQUEST['eintrag'])
			{
				if(trim($_POST['komment']) != '')
				{
					$eintraege[$a] = trim($eintraege[$a]).'<ul><li style="list-style: none"><i>'.$_POST['komment'].'</i></li></ul>'."\r\n";
				}
			}
			flock($openfile,2);
			fwrite($openfile,$eintraege[$a]);
			flock($openfile,3);
		}
		fclose($openfile);
	}

	include('../myGB-lib/bbcode.php');
	
	if (!isset($_REQUEST['page'])) $page = 1;
	else $page = (int) $_REQUEST['page'];
	
	$eintraege = @file('../../'.$textfile);
	$start = (count($eintraege) - 1) - $seiten * ($page - 1);
	$stop = (count($eintraege) - 1) - $seiten * ($page - 1) - $seiten + 1;
	if ($start > (count($eintraege) - 1)) $start = count($eintraege) - 1;
	
	if ($stop < 0) $stop = 0;

	if( ($eintraege > 0) and isset($eintraege) )
	{
		$max = count($eintraege);
		for ($a = $start; $a >= $stop; $a--)
		{
			$Eintrag = explode("|", $eintraege[$a]);
			$Eintrag[4] = str_replace('src="'.$smileypath, 'src="../../'.$smileypath, $Eintrag[4]);
			$Eintrag[4] = str_replace("src='".$smileypath, "src='../../".$smileypath, $Eintrag[4]);
?>
	<form action="frame.php?<?php echo htmlspecialchars(SID); ?>" method="POST">

	<table style="border: 1px solid #000000; width: 500px; margin: auto" cellpadding="0" cellspacing="0">
	<tr>
		<td rowspan="3" style="padding: 0.1em; width: 50px; text-align: center; border-right: 1px solid #000000">
			<a onclick="return confirm('Wirklich lschen?');" href="frame.php?id=<?php echo session_id();?>&del=true&eintrag=<?php echo $a;?>"><img src="../../smilies/form/del.gif"></a>
		</td>
		<td style="padding: 0.1em;">
			<b><?php echo $Eintrag[0];?></b> &nbsp;
			am  <b><?php echo $Eintrag[3];?></b> &nbsp;
			<?php if($Eintrag[2]=='') { echo'&nbsp;'; } else { echo ' <a href="mailto:'.$Eintrag[2].'"><img src="../../smilies/mail.gif"></a> &nbsp; '; } ?>
			<?php if(($Eintrag[1]=='')or($Eintrag[1]=='http://')) { echo'&nbsp;'; } else { echo ' <a href="'.$Eintrag[1].'" target="_blank"><img src="../../smilies/hpage.gif"></a> &nbsp;'; } ?>
		</td>
	</tr>
	<tr>
		<td style="padding: 0.3em;; overflow: auto">
			<?php echo myGB_bbcodesmilie(stripslashes(nl2br($Eintrag[4])), true) ?>
		</td>
	</tr>
	<tr align="center">
		<td style="text-align: center; border-top: 1px solid #000000; padding: 0.1em;">
			Kommentar: <input type="text" name="komment">
			<input type="submit" name="submit" value="Kommentieren">
			<input type="hidden" name="eintrag" value="<?php echo $a;?>">
		</td>
	</tr>
	</table>
	<br>
	
	</form>

<?php
		}
	}
?>
	<div class="links">
<?php

	if( !isset($max) or $max == '' ) $max = 0;
	
	if ($max == 0) $pages = 1;
	else $pages = intval(($max - 1) / $seiten) + 1;

	// Links zu den einzelnen Seiten ausgeben
	for ($i = 1; $i <= $pages; $i++)
	{
		if ($i == $page) echo ' <b>['.$i.']</b> ';
		else echo ' <a href="'.$_SERVER['PHP_SELF'].'?'.htmlspecialchars(SID).'&page='.$i.'">'.$i.'</a> ';
	}
?>
	<br>Es sind <b><?php echo $max; ?></b> Eintr&auml;ge im G&auml;stebuch<br><br>
	
	</div>
	
	</div>
	
</body>
</html>
